# shaksz

All coding and design solutions as package.


[![build-release-package](https://github.com/vermavarun/shaksz/actions/workflows/build.yaml/badge.svg)](https://github.com/vermavarun/shaksz/actions/workflows/build.yaml)

# How to install 💫

⭐ __PIP:__ ⭐

```code
pip install shaksz
```

__GitHub(ssh)__:
```code
pip install git+ssh://git@github.com/vermavarun/shaksz
```

__GitHub(https)__:
```code
pip install git+https://github.com/vermavarun/shaksz.git
```

__GitHub(Token)__:
```code
pip install git+https://<TOKEN>@github.com/vermavarun/shaksz.git
```


# Consumption ⚙️
```python
    import shaksz

    result = shaksz.leetcode.twoSum([2, 7, 11, 15], 9)

    print(result)

    result = shaksz.codeforces._4a(input_data)

    print(result)
```
